@@ -452,7 +452,7 @@ process_preprocessed_file(Context& ctx, Hash& hash, const std::string& path)
 {
   auto data = util::read_file<std::string>(path);
   if (!data) {
-    LOG("Failed reading {}: {}", path, data.error());
+    LOG("Failed to read {}: {}", path, data.error());
     return nonstd::make_unexpected(Statistic::internal_error);
   }
 
@@ -633,7 +633,7 @@ result_key_from_depfile(Context& ctx, Hash& hash)
   const auto file_content =
     util::read_file<std::string>(ctx.args_info.output_dep);
   if (!file_content) {
-    LOG("Cannot open dependency file {}: {}",
+    LOG("Failed to read dependency file {}: {}",
         ctx.args_info.output_dep,
         file_content.error());
     return std::nullopt;
@@ -763,7 +763,9 @@ do_execute(Context& ctx, Args& args, const bool capture_stdout = true)
   if (capture_stdout) {
     auto stdout_data_result = util::read_file<util::Bytes>(tmp_stdout.path);
     if (!stdout_data_result) {
-      // The stdout file was removed - cleanup in progress? Better bail out.
+      LOG("Failed to read {} (cleanup in progress?): {}",
+          tmp_stdout.path,
+          stdout_data_result.error());
       return nonstd::make_unexpected(Statistic::missing_cache_file);
     }
     stdout_data = *stdout_data_result;
@@ -771,7 +773,9 @@ do_execute(Context& ctx, Args& args, const bool capture_stdout = true)
 
   auto stderr_data_result = util::read_file<util::Bytes>(tmp_stderr.path);
   if (!stderr_data_result) {
-    // The stdout file was removed - cleanup in progress? Better bail out.
+    LOG("Failed to read {} (cleanup in progress?): {}",
+        tmp_stderr.path,
+        stderr_data_result.error());
     return nonstd::make_unexpected(Statistic::missing_cache_file);
   }
 
@@ -1372,11 +1376,23 @@ hash_common_info(const Context& ctx,
 
   // Hash variables that may affect the compilation.
   const char* always_hash_env_vars[] = {
-    // From <https://gcc.gnu.org/onlinedocs/gcc/Environment-Variables.html>:
+    // From <https://gcc.gnu.org/onlinedocs/gcc/Environment-Variables.html>
+    // (note: SOURCE_DATE_EPOCH is handled in hash_source_code_string()):
     "COMPILER_PATH",
     "GCC_COMPARE_DEBUG",
     "GCC_EXEC_PREFIX",
-    // Note: SOURCE_DATE_EPOCH is handled in hash_source_code_string().
+    // Variables that affect which underlying compiler ICC uses. Reference:
+    // <https://www.intel.com/content/www/us/en/develop/documentation/
+    // mpi-developer-reference-windows/top/environment-variable-reference/
+    // compilation-environment-variables.html>
+    "I_MPI_CC",
+    "I_MPI_CXX",
+#ifdef __APPLE__
+    // On macOS, /usr/bin/clang is a compiler wrapper that switches compiler
+    // based on at least these variables:
+    "DEVELOPER_DIR",
+    "MACOSX_DEPLOYMENT_TARGET",
+#endif
   };
   for (const char* name : always_hash_env_vars) {
     const char* value = getenv(name);
